
  - For a list of bug fixes, see 
    https://github.com/radical-cybertools/radical.synapse/issues?q=is%3Aissue+is%3Aclosed+sort%3Aupdated-desc
  - For a list of open issues and known problems, see
    https://github.com/radical-cybertools/radical.synapse/issues?q=is%3Aissue+is%3Aopen+


0.41 Release                                                          2016-02-23
--------------------------------------------------------------------------------

  - add walltime sampler
  - replace multiprocessing.Queue with Queue.Queue (former breaks on Gordon)


0.40 Release                                                          2016-02-10
--------------------------------------------------------------------------------

  - add a CHANGES.md :)
  - make RADICAL_SYNAPSE_WATCHMODE default to None on emulate()

--------------------------------------------------------------------------------


